@@ -15,7 +15,8 @@
 
 import tower_cli
 from tower_cli.api import client
-from tower_cli.utils import exceptions as exc
+from tower_cli import exceptions as exc
+from tower_cli.constants import CUR_API_VERSION
 
 from tests.compat import unittest, mock
 
@@ -102,7 +103,7 @@ class CreateTests(unittest.TestCase):
 
     def test_create_wait(self):
         """Establish that a project can be created with the wait flag
-        enabled and still sucessfully exit and complete.
+        enabled and still successfully exit and complete.
         """
         with client.test_mode as t:
 
@@ -116,7 +117,9 @@ class CreateTests(unittest.TestCase):
             t.register_json(
                 '/projects/42/', {
                     'status': 'successful',
-                    'related': {'last_update': '/api/v1/project_updates/21/'}
+                    'related': {
+                        'last_update': '/api/%s/project_updates/21/' % CUR_API_VERSION
+                    }
                 },
                 method='GET'
             )
@@ -162,14 +165,14 @@ class UpdateTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'name': 'frobnicate',
-                'related': {'update': '/api/v1/projects/1/update/'},
+                'related': {'update': '/api/%s/projects/1/update/' % CUR_API_VERSION},
             })
             t.register_json('/projects/1/update/', {'can_update': True},
                             method='GET')
             t.register_json('/projects/1/update/', {'project_update': 42},
                             method='POST')
             result = self.res.update(1)
-            self.assertEqual(result, {'changed': True})
+            self.assertEqual(result, {'changed': True, 'id': 42})
 
     def test_basic_update_with_monitor(self):
         """Establish that we are able to create a project update
@@ -179,7 +182,7 @@ class UpdateTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'name': 'frobnicate',
-                'related': {'update': '/api/v1/projects/1/update/'},
+                'related': {'update': '/api/%s/projects/1/update/' % CUR_API_VERSION},
             })
             t.register_json('/projects/1/update/', {'can_update': True},
                             method='GET')
@@ -201,7 +204,7 @@ class UpdateTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'name': 'frobnicate',
-                'related': {'update': '/api/v1/projects/1/update/'},
+                'related': {'update': '/api/%s/projects/1/update/' % CUR_API_VERSION},
             })
             t.register_json('/projects/1/update/', {'can_update': False},
                             method='GET')
@@ -224,7 +227,7 @@ class StatusTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'related': {'last_update':
-                            '/api/v1/projects/1/project_updates/42/'},
+                            '/api/%s/projects/1/project_updates/42/' % CUR_API_VERSION},
             })
             t.register_json('/projects/1/project_updates/42/', {
                 'elapsed': 1335024000.0,
@@ -248,7 +251,7 @@ class StatusTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'related': {'last_update':
-                            '/api/v1/projects/1/project_updates/42/'},
+                            '/api/%s/projects/1/project_updates/42/' % CUR_API_VERSION},
             })
             t.register_json('/projects/1/project_updates/42/', {
                 'elapsed': 1335024000.0,
@@ -273,8 +276,8 @@ class StatusTests(unittest.TestCase):
             t.register_json('/projects/1/', {
                 'id': 1,
                 'related': {
-                    'current_update': '/api/v1/projects/1/project_updates/42/',
-                    'last_update': '/api/v1/projects/1/project_updates/41/',
+                    'current_update': '/api/%s/projects/1/project_updates/42/' % CUR_API_VERSION,
+                    'last_update': '/api/%s/projects/1/project_updates/41/' % CUR_API_VERSION,
                 },
             })
             t.register_json('/projects/1/project_updates/42/', {
