@@ -32,6 +32,16 @@ from six import StringIO
 __all__ = ['settings', 'with_global_options', 'pop_option']
 
 
+tower_dir = '/etc/tower/'
+user_dir = os.path.expanduser('~')
+CONFIG_FILENAME = '.tower_cli.cfg'
+CONFIG_OPTIONS = frozenset((
+    'host', 'username', 'password', 'verify_ssl', 'format',
+    'color', 'verbose', 'description_on', 'certificate',
+    'use_token', 'oauth_token'
+))
+
+
 class Parser(configparser.ConfigParser):
     """ConfigParser subclass that doesn't strictly require section
     headers.
@@ -49,7 +59,7 @@ class Parser(configparser.ConfigParser):
         # other users, raise a warning
         if os.path.isfile(fpname):
             file_permission = os.stat(fpname)
-            if fpname != '/etc/tower/tower_cli.cfg' and (
+            if fpname != os.path.join(tower_dir, 'tower_cli.cfg') and (
                 (file_permission.st_mode & stat.S_IRGRP) or
                 (file_permission.st_mode & stat.S_IROTH)
             ):
@@ -78,7 +88,8 @@ class Settings(object):
         - user: Contents parsed from .ini-formatted file ``~/.tower_cli.cfg`` if exists.
         - local: Contents parsed from .ini-formatted file ``.tower_cli.cfg`` if exists in the present working
           directory or any parent directories.
-        - runtime: keyworded arguements provided by ``settings.runtime_values`` context manager.
+        - environment: Values from magic environment variables.
+        - runtime: keyworded arguments provided by ``settings.runtime_values`` context manager.
 
     Note that .ini configuration file should follow the specified format in order to be correctly parsed:
 
@@ -90,7 +101,7 @@ class Settings(object):
        ...
 
     """
-    _parser_names = ['runtime', 'local', 'user', 'global', 'defaults']
+    _parser_names = ['runtime', 'environment', 'local', 'user', 'global', 'defaults']
 
     @staticmethod
     def _new_parser(defaults=None):
@@ -109,23 +120,26 @@ class Settings(object):
 
         # Initialize the data dictionary for the default level
         # precedence (that is, the bottom of the totem pole).
-        defaults = {
+        defaults = {}
+        for key in CONFIG_OPTIONS:
+            defaults[key] = ''
+        defaults.update({
             'color': 'true',
             'format': 'human',
             'host': '127.0.0.1',
-            'password': '',
-            'username': '',
             'verify_ssl': 'true',
             'verbose': 'false',
             'description_on': 'false',
-            'certificate': '',
             'use_token': 'false',
-        }
+        })
         self._defaults = self._new_parser(defaults=defaults)
 
+        # environment variables as defaults
+        self._environment = self._new_parser(defaults=config_from_environment())
+
         # If there is a global settings file, initialize it.
         self._global = self._new_parser()
-        if os.path.isdir('/etc/tower/'):
+        if os.path.isdir(tower_dir):
             # Sanity check: Try to get a list of files in `/etc/tower/`.
             #
             # The default Tower installation caused `/etc/tower/` to have
@@ -139,7 +153,7 @@ class Settings(object):
             # Therefore, check for that particular problem and give a warning
             # if we're in that situation.
             try:
-                os.listdir('/etc/tower/')
+                os.listdir(tower_dir)
             except OSError:
                 warnings.warn('/etc/tower/ is present, but not readable with '
                               'current permissions. Any settings defined in '
@@ -148,13 +162,13 @@ class Settings(object):
 
             # If there is a global settings file for Tower CLI, read in its
             # contents.
-            self._global.read('/etc/tower/tower_cli.cfg')
+            self._global.read(os.path.join(tower_dir, 'tower_cli.cfg'))
 
         # Initialize a parser for the user settings file.
         self._user = self._new_parser()
 
         # If there is a user settings file, read it into the parser object.
-        user_filename = os.path.expanduser('~/.tower_cli.cfg')
+        user_filename = os.path.join(user_dir, CONFIG_FILENAME)
         self._user.read(user_filename)
 
         # Initialize a parser for the local settings file.
@@ -162,27 +176,24 @@ class Settings(object):
 
         # If there is a local settings file in the current working directory
         # or any parent, read it into the parser object.
-        #
-        # As a first step, we need to get each of the parents.
-        cwd = os.getcwd()
-        local_dirs = []
-        for i in range(0, len(cwd.split('/'))):
-            local_dir = '/'.join(cwd.split('/')[0:i + 1])
-            if len(local_dir) == 0:
-                local_dir = '/'
+        local_dir = os.getcwd()
+        local_dirs = [local_dir] if local_dir not in (user_dir, tower_dir) else []
+
+        # Loop while there are 2 parts to local_dir
+        while os.path.split(local_dir)[1]:
+
+            # Switch to parent of this directory
+            local_dir, _ = os.path.split(local_dir)
 
             # Sanity check: if this directory corresponds to our global or
             # user directory, skip it.
-            if local_dir in (os.path.expanduser('~'), '/etc/tower'):
-                continue
-
-            # Add this directory to the list.
-            local_dirs.append(local_dir)
+            if local_dir not in (user_dir, tower_dir):
+                local_dirs = [local_dir] + local_dirs
 
         # Iterate over each potential local config file and attempt to read
         # it (most won't exist, which is fine).
         for local_dir in local_dirs:
-            local_filename = '%s/.tower_cli.cfg' % local_dir
+            local_filename = os.path.join(local_dir, CONFIG_FILENAME)
             self._local.read(local_filename)
 
         # Put a stubbed runtime parser in.
@@ -273,7 +284,6 @@ class Settings(object):
 
         =====API DOCS=====
         """
-        kwargs = config_from_environment(kwargs)
 
         # Coerce all values to strings (to be coerced back by configparser
         # later) and defenestrate any None values.
@@ -311,20 +321,16 @@ class Settings(object):
                 self._cache.pop(k, None)
 
 
-def config_from_environment(kwargs):
+def config_from_environment():
     """Read tower-cli config values from the environment if present, being
     careful not to override config values that were explicitly passed in.
     """
-    CONFIG_OPTIONS = ('host', 'username', 'password', 'verify_ssl', 'format',
-                      'color', 'verbose', 'description_on', 'certificate',
-                      'use_token')
-    kwargs = copy.copy(kwargs)
+    kwargs = {}
     for k in CONFIG_OPTIONS:
-        if k not in kwargs or kwargs[k] is None:
-            env = 'TOWER_' + k.upper()
-            v = os.getenv(env, None)
-            if v is not None:
-                kwargs[k] = v
+        env = 'TOWER_' + k.upper()
+        v = os.getenv(env, None)
+        if v is not None:
+            kwargs[k] = v
     return kwargs
 
 
@@ -338,8 +344,9 @@ def _apply_runtime_setting(ctx, param, value):
 
 
 SETTINGS_PARMS = set([
-    'tower_host', 'tower_password', 'format', 'tower_username', 'verbose',
-    'description_on', 'insecure', 'certificate', 'use_token'
+    'tower_host', 'tower_oauth_token', 'tower_password', 'format',
+    'tower_username', 'verbose', 'description_on', 'insecure', 'certificate',
+    'use_token'
 ])
 
 
@@ -372,6 +379,14 @@ def with_global_options(method):
         required=False, callback=_apply_runtime_setting,
         is_eager=True
     )(method)
+    method = click.option(
+        '-t', '--tower-oauth-token',
+        help='OAuth2 token to use to authenticate to Ansible Tower. '
+             'This will take precedence over a token provided to '
+             '`tower config`, if any.',
+        required=False, callback=_apply_runtime_setting,
+        is_eager=True
+    )(method)
     method = click.option(
         '-u', '--tower-username',
         help='Username to use to authenticate to Ansible Tower. '
@@ -440,8 +455,8 @@ def with_global_options(method):
     method = click.option(
         '--use-token',
         default=None,
-        help='Turn on Tower\'s token-based authentication. Set config'
-             ' use_token to make this permanent.',
+        help='Turn on Tower\'s token-based authentication. No longer supported '
+             'in Tower 3.3 and above.',
         is_flag=True,
         required=False, callback=_apply_runtime_setting,
         is_eager=True
