@@ -19,5 +19,5 @@ from __future__ import absolute_import, unicode_literals
 
 from tower_cli.models.base import (Resource, MonitorableResource, ExeResource, BaseResource, SurveyResource,
                                    ReadOnlyResource)
-from tower_cli.models.fields import Field
+from tower_cli.models.fields import Field, ManyToManyField
 from tower_cli.cli.types import File
