@@ -44,14 +44,33 @@ class Resource(models.Resource):
     workflow_job_template = models.Field(
         key='-W', type=types.Related('workflow'))
     unified_job_template = models.Field(required=False)
+
+    # Prompts
+    extra_data = models.Field(type=types.Variables(), required=False,
+                              display=False, help_text='Extra data for '
+                              'schedule rules in the form of a .json file.')
     inventory = models.Field(
         type=types.Related('inventory'), required=False, display=False)
     credential = models.Field(
         type=types.Related('credential'), required=False, display=False)
+    credentials = models.ManyToManyField('credential')
     job_type = models.Field(required=False, display=False)
     job_tags = models.Field(required=False, display=False)
     skip_tags = models.Field(required=False, display=False)
     limit = models.Field(required=False, display=False)
+    diff_mode = models.Field(type=bool, required=False, display=False)
+    verbosity = models.Field(
+        display=False,
+        type=types.MappedChoice([
+            (0, 'default'),
+            (1, 'verbose'),
+            (2, 'more_verbose'),
+            (3, 'debug'),
+            (4, 'connection'),
+            (5, 'winrm'),
+        ]),
+        required=False,
+    )
 
     def __new__(cls, *args, **kwargs):
         for attr in ['create', 'modify', 'list']:
