@@ -26,6 +26,8 @@ class Resource(models.Resource, models.MonitorableResource):
     cli_help = 'Manage projects within Ansible Tower.'
     endpoint = '/projects/'
     unified_job_type = '/project_updates/'
+    dependencies = ['organization', 'credential']
+    related = ['notification_templates', 'schedules']
 
     name = models.Field(unique=True)
     description = models.Field(required=False, display=False)
@@ -38,7 +40,7 @@ class Resource(models.Resource, models.MonitorableResource):
             ('hg', 'hg'),
             ('svn', 'svn'),
             ('insights', 'insights'),
-        ]),
+        ]), required=False
     )
     scm_url = models.Field(required=False)
     local_path = models.Field(
@@ -95,7 +97,7 @@ class Resource(models.Resource, models.MonitorableResource):
                                 be updated to the provided values.; If unset, a match causes the request to be
                                 a no-op.
         :type force_on_exists: bool
-        :param `**kwargs`: Keyword arguements which, all together, will be used as POST body to create the
+        :param `**kwargs`: Keyword arguments which, all together, will be used as POST body to create the
                            resource object.
         :returns: A dictionary combining the JSON output of the created resource, as well as two extra fields:
                   "changed", a flag indicating if the resource is created successfully; "id", an integer which
@@ -169,7 +171,7 @@ class Resource(models.Resource, models.MonitorableResource):
         :param create_on_missing: Flag that if set, a new object is created if ``pk`` is not set and objects
                                   matching the appropriate unique criteria is not found.
         :type create_on_missing: bool
-        :param `**kwargs`: Keyword arguements which, all together, will be used as PATCH body to modify the
+        :param `**kwargs`: Keyword arguments which, all together, will be used as PATCH body to modify the
                            resource object. if ``pk`` is not set, key-value pairs of ``**kwargs`` which are
                            also in resource's identity will be used to lookup existing reosource.
         :returns: A dictionary combining the JSON output of the modified resource, as well as two extra fields:
